<?php
/*
 Plugin Name: Post List Generator
Plugin URI: http://residentbird.main.jp/bizplugin/
Description: 記事（投稿・固定ページの一覧を作成するプラグインです
Version: 1.0.0
Author:WordPress Biz Plugin
Author URI: http://residentbird.main.jp/bizplugin/
*/

include_once "admin-ui.php";
new PostListGeneratorPlugin();

class PLG
{
	const SHORTCODE = "showpostlist";
	const OPTIONS = "post_list_options";

	public static function get_option(){
		return get_option(self::OPTIONS);
	}

	public static function update_option( $options ){
		if ( empty($options)){
			return;
		}
		update_option(self::OPTIONS, $options);
	}

	public static function enqueue_css_js(){
		wp_enqueue_style('post-list-css', plugins_url('post-list-generator.css', __FILE__ ));
		wp_enqueue_script('post-list-js', plugins_url('next-page.js', __FILE__ ), array('jquery'));
	}

	public static function localize_js(){
		wp_localize_script( 'post-list-js', 'PLG_Setting', array(
				'ajaxurl' => admin_url('admin-ajax.php'),
				'action' => 'get_post_ajax',
				'next_page' => '1'
		));
	}
}

/**
 * プラグイン本体
 */
class PostListGeneratorPlugin{

	var $adminUi;

	public function __construct(){
		register_activation_hook(__FILE__, array(&$this,'on_activation'));
		add_action( 'init', array(&$this,'on_init') );
		add_action( 'admin_init', array(&$this,'on_admin_init') );
		add_action( 'admin_menu', array(&$this, 'on_admin_menu'));
		add_action( 'wp_ajax_get_post_ajax', array(&$this,'get_post_ajax') );
		add_action( 'wp_ajax_nopriv_get_post_ajax', array(&$this,'get_post_ajax') );
		add_shortcode( PLG::SHORTCODE, array(&$this,'show_shortcode'));
	}

	function on_activation() {
		$option = PLG::get_option();
		if( $option ) {
			return;
		}
		$arr = array(
				"content_type" => "投稿",
				"orderby" => "公開日順",
				"numberposts" => "30"
		);
		PLG::update_option( $arr );
	}

	function on_init() {
		if ( is_admin() ) {
			return;
		}
		PLG::enqueue_css_js();
		PLG::localize_js();
	}

	function on_admin_init() {
		$this->adminUi = new PLGAdminUi(__FILE__);
	}

	public function on_admin_menu() {
		add_options_page("Post List設定", "Post List設定", 'administrator', __FILE__, array(&$this->adminUi, 'show_admin_page'));
	}

	/**
	 * shortcode
	 */
	function show_shortcode(){
		$info = new PostListInfo();
		ob_start();
		include('post-list-view.php');
		$contents = ob_get_contents();
		ob_end_clean();
		return $contents;
	}

	/**
	 * Ajax
	 */
	function get_post_ajax(){
		$page = absint( $_REQUEST[page] );
		if ( $page == 0){
			die();
		}
		$info = new PostListInfo( $page );

		ob_start();
		include('post-table.php');
		$content = ob_get_contents();
		ob_end_clean();

		$charset = get_bloginfo( 'charset' );
		$next = $info->has_next ? $page + 1: null;
		$array = array( 'html' => $content, next_page => $next );
		$json = json_encode( $array );
		nocache_headers();
		header( "Content-Type: application/json; charset=$charset" );
		echo $json;
		die();
	}
}


class PostListInfo{
	var $items = array();
	var $has_next = false;

	public function __construct( $page = 0){
		$options = PLG::get_option();

		$condition = array();
		if ( $options['content_type'] == '投稿'){
			$condition['post_type'] = 'post';
		}else if ( $options['content_type'] == '固定ページ' ){
			$condition['post_type'] = 'page';
		}else{
			$condition['post_type'] = array('page', 'post');
		}
		$condition['numberposts'] = $options['numberposts'] + 1;
		$condition['order'] = 'desc';
		$condition['offset'] = $page * $options['numberposts'];
		$condition['orderby'] = $options['orderby'] == '公開日順' ? 'post_date' : 'modified';

		$posts = get_posts( $condition );
//  	var_dump($options, $condition, $posts);

		if ( !is_array($posts) ){
			return;
		}

		if ( count($posts) > $options['numberposts']){
			$this->has_next = true;
			array_pop ( $posts );
		}

		foreach($posts as $post){
			$this->items[] = new PostListItem($post, $options);
		}
	}
}

class PostListItem{
	var $date;
	var $title;
	var $url;

	public function __construct( $post, $options ){
		$raw_date = $options['orderby'] == '公開日順' ? $post->post_date : $post->post_modified;
		$this->date = date("Y-m-d", strtotime($raw_date));
		$this->title = esc_html( $post->post_title );
		$this->url = get_permalink($post->ID);
	}
}

?>